
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL

#include "TransformableImageView.h"

#include <Foundation/NSString.h>
#include <Foundation/NSException.h>
#include <AppKit/NSAffineTransform.h>
#include <AppKit/NSImage.h>
#include <AppKit/NSImageRep.h>


/*
 * Non-Public methods.
 */
@interface TransformableImageView(Private)
- (void) adjustScaling;
@end

/*
 */
@implementation TransformableImageView

/*
 * Designated initializer.
 */
- (id) initWithFrame: (NSRect)frame
{
   if (self = [super initWithFrame: frame])
   {
      myImage = nil;
   }

   return self;
}


- (void) dealloc
{
   NSLog(@"dealloc TransformableImageView, retain count is %d", [self retainCount]);

   [self setImage: nil];

   [super dealloc];
}


/*
 * Set the image to be displayed by this view.
 */
- (void) setImage: (NSImage*)image
{
   [myImage release];
   myImage = [image retain];
   [self setNeedsDisplay: YES];
}


/*
 * Get the image that is displayed by this view. Returns
 * nil if no image has been set.
 */
- (NSImage*) image
{
   return myImage;
}


- (void) drawRect: (NSRect)aRect
{
   NSImageRep* imageRep;
   NSRect      drawRect;
   //id          transform;

   if ([self image])
   {
      //transform = [NSAffineTransform transform];
      //[transform rotateByDegrees: 10];
      //[transform scaleBy: 0.5];
      //[transform concat];

      //[self adjustScaling];

      imageRep = [[self image] bestRepresentationForDevice: nil];
      NSAssert(imageRep != nil, @"no image representation found");

      drawRect = NSMakeRect(0,
                            0,
                            [[self image] size].width,
                            [[self image] size].height);

      [imageRep drawInRect: drawRect];
   }
}


/*
 * Adjust the scale factor for the image so that the
 * image will completely fill the image view.
 */
- (void) adjustScaling
{
   float   wScale;
   float   hScale;
   id      scaleTransform;
   NSSize  imageSize;
   NSSize  viewSize;

   imageSize = [[self image] size];
   viewSize  = [self frame].size;
      
   wScale = viewSize.width / imageSize.width;
   hScale = viewSize.height / imageSize.height;

   scaleTransform = [NSAffineTransform transform];
   [scaleTransform scaleBy: (wScale < hScale ? wScale : hScale)];
   [scaleTransform concat];
}


@end
