
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL


#include "ViewablePDFPage.h"
#include "ViewablePDFDocument.h"
#include "PageCache.h"
#include "PDFRenderer.h"

#include <Foundation/NSString.h>
#include <Foundation/NSException.h>
#include <AppKit/NSImage.h>


/*
 * Non-Public methods.
 */
@interface ViewablePDFPage(Private)
@end


/*
 * An instance of this class represents on page
 * of PDF document that can be displayed by
 * ViewIt.
 */
@implementation ViewablePDFPage

/*
 * Designated initializer.
 */
- (id) initWithDocument: (ViewablePDFDocument*)aDocument pageNumber: (int)num
{
   if (self = [super initWithImage: nil pageNumber: num])
   {
      myDocument = aDocument;
   }

   return self;
}


- (void) dealloc
{
   NSLog(@"dealloc ViewablePDFPage, retain count is %d", [self retainCount]);

   [super dealloc];
}


- (NSImage*) image
{
   // image is retained by the cache, so the page does
   // not need to retain it (it is event not desired because
   // this will cause memory leaks.
   return [[myDocument cache] imageForPage: [self pageNumber]];

   //[self updateImage: [[myDocument renderer] renderPage: [self pageNumber]]];
   //return [super image];
}


/*
 * This page is able to produce scaled images by itself.
 * This is desirable because fonts look better when the
 * page image is re-rendered with the new scale factor.
 */
- (BOOL) canScale
{
   return YES;
   //return NO;
}


- (NSImage*) imageScaledBy: (double)factor
{
   [myDocument setScaleFactor: factor];
   return [self image];
}


@end
