
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL


#include "ViewablePage.h"
#include "ViewableDocument.h"

#include <Foundation/NSString.h>
#include <Foundation/NSException.h>
#include <AppKit/NSImage.h>

/*
 * A ViewablePage is intended to abstract the representation
 * of a document from it's format. For ViewIt, a document is
 * simply a set of displayable (viewable) pages. It does not
 * whether this pages originate eg. to an image file or a
 * text document (as long as an image can be produced from
 * the documents source).
 */
@implementation ViewablePage

-(id)init
{
   return [self initWithImage: nil];
}


- (id) initWithImage: (NSImage*)anImage
{
   return [self initWithImage: anImage pageNumber: 1];
}


/*
 * designated initializer.
 */
- (id) initWithImage: (NSImage*)anImage pageNumber: (int)pageNumber
{
   if (self = [super init])
   {
      [self updateImage: anImage];
      [self setPageNumber: pageNumber];
   }

   return self;
}


- (void) dealloc
{
   NSLog(@"dealloc ViewablePage, retain count is %d", [self retainCount]);

   [self updateImage: nil];

   [super dealloc];
}


- (void) setPageNumber: (int)num
{
   NSAssert(num > 0, @"invalid page number (<= 0)");
   pageNum = num;
}


- (int) pageNumber
{
   return pageNum;
}


- (NSImage*) image
{
   return myImage;
}


/*
 * Returns a new (autoreleased) image that is derived
 * from the page's original image scaled by the specified
 * factor.
 */
- (NSImage*) imageScaledBy: (double)factor
{
   /*
   NSImage* scaledImage;
   NSSize   unscaledSize;

   scaledImage = [[NSImage alloc] initWithData: [[self image] TIFFRepresentation]];
   [scaledImage autorelease];

   [scaledImage setScalesWhenResized: YES];
   unscaledSize = [scaledImage size];
   [scaledImage setSize: NSMakeSize(unscaledSize.width * factor,
                                    unscaledSize.height * factor)];
   
   return scaledImage;
   */

   [[self image] setScalesWhenResized: YES];
   [[self image] setSize: NSMakeSize(imageBaseSize.width * factor,
                                     imageBaseSize.height * factor)];

   return [self image];
}


/*
 * This default implementation does not provide the possiblity
 * to retrieved a scaled page image. This is done by the view
 * when this method returns NO. Overwrite this method is subclasses
 * to return YES if your page is able to provide a scaled image.
 */
- (BOOL) canScale
{
   return YES;
}


- (void) updateImage:(NSImage*)anImage
{
   [myImage release];

   if (anImage != nil)
   {
      myImage = [anImage retain];
      imageBaseSize = [anImage size];
   }
}


/*
 * No minipages in first versions, so this
 * method will return NO in any case.
 */
- (BOOL) providesMinipage
{
   return NO;
}


/*
 * No minipages in first versions, so this
 * method will return nil in any case.
 */
- (NSImage*) minipage
{
   return nil;
}


@end
