
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL


#include "XPDFBridge.h"
#include "PDFDoc.h"
#include "PSOutputDev.h"
#include "GString.h"
#include "GlobalParams.h"

#include <stdlib.h>


/* ----------------------------------------------------------- */

/* 
 * PDFDoc class 
 */

#define TO_PDFDoc(object) ((PDFDoc*)object)

XPDFObject PDFDoc_create(const char* filename,
                         const char* ownerPassword,
                         const char* userPassword)
{
   GString* gsFilename;
   GString* gsOwnerPassword;
   GString* gsUserPassword;

   gsFilename = new GString(filename);
   gsOwnerPassword = (ownerPassword != NULL ? new GString(ownerPassword) : NULL);
   gsUserPassword  = (userPassword != NULL ? new GString(userPassword) : NULL);

   return (XPDFObject)(new PDFDoc(gsFilename, gsOwnerPassword, gsUserPassword));
}


void PDFDoc_delete(XPDFObject pdfDoc)
{
   delete TO_PDFDoc(pdfDoc);
}


int PDFDoc_isOk(XPDFObject pdfDoc)
{
   return TO_PDFDoc(pdfDoc)->isOk();
}


int PDFDoc_getErrorCode(XPDFObject pdfDoc)
{
   return TO_PDFDoc(pdfDoc)->getErrorCode();
}


double PDFDoc_getPageWidth(XPDFObject pdfDoc, int pageNum)
{
   return TO_PDFDoc(pdfDoc)->getPageWidth(pageNum);
}


double PDFDoc_getPageHeight(XPDFObject pdfDoc, int pageNum)
{
   return TO_PDFDoc(pdfDoc)->getPageHeight(pageNum);
}


int PDFDoc_getPageRotate(XPDFObject pdfDoc, int pageNum)
{
   return TO_PDFDoc(pdfDoc)->getPageRotate(pageNum);
}


int PDFDoc_getNumPages(XPDFObject pdfDoc)
{
   return TO_PDFDoc(pdfDoc)->getNumPages();
}

 
const char* PDFDoc_getMetaData(XPDFObject pdfDoc)
{
   return (const char*)TO_PDFDoc(pdfDoc)->readMetadata();
}

/* ----------------------------------------------------------- */

/*
 * Renderer
 */

RenderResult Renderer_render(XPDFObject     pdfDoc,
                             void*          outputFunc,
                             void*          outputStream,
                             OutputOptions* options)
{
   GlobalParams*  params;
   RenderResult   rc = RenderResult_Ok;
   PSOutputDev*   psOut;

   params = new GlobalParams("");

   params->setPSLevel(psLevel2);
   
   if (options->paperWidth != 0)
   {
      params->setPSPaperWidth(options->paperWidth);
   }
   if (options->paperHeight != 0)
   {
      params->setPSPaperHeight(options->paperHeight);
   }

   psOut = new PSOutputDev((PSOutputFunc)outputFunc,
                           outputStream,
                           TO_PDFDoc(pdfDoc)->getXRef(),
                           TO_PDFDoc(pdfDoc)->getCatalog(),
                           options->firstPage,
                           options->lastPage,
                           psModePS,
                           params);

   if (psOut->isOk())
   {
      TO_PDFDoc(pdfDoc)->displayPages(psOut,
                                      options->firstPage,
                                      options->lastPage,
                                      options->resolution,
                                      0,
                                      gFalse,
                                      params);
   }
   else
   {
      rc = RenderResult_ErrorOutputDevice;
   }


   delete psOut;
   delete params;

   return rc;
}
