
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL

#ifndef _H_XPDF_OBJC_BRIDGE
#define _H_XPDF_OBJC_BRIDGE

#include <stdlib.h>

/*
 * 'Bridge-Functions' to create a Objective-C
 * Interface to (a part of) the XPDF System.
 */

typedef void* XPDFObject;

typedef struct OutputOptions
{
   int  resolution;
   int  firstPage;
   int  lastPage;
   int  paperWidth;
   int  paperHeight;
} OutputOptions;

typedef enum RenderResult
{
   RenderResult_Ok,
   RenderResult_ErrorOutputDevice,
   RenderResult_MiscError
} RenderResult;



#ifdef __cplusplus 
extern "C" {
#endif

 /* 
  * PDFDoc class 
  */
 XPDFObject PDFDoc_create(const char* filename,
                          const char* ownerPassword,
                          const char* userPassword);
 void PDFDoc_delete(XPDFObject pdfDoc);

 int PDFDoc_isOk(XPDFObject pdfDoc);
 int PDFDoc_getErrorCode(XPDFObject pdfDoc);

 double PDFDoc_getPageWidth(XPDFObject pdfDoc, int pageNum);
 double PDFDoc_getPageHeight(XPDFObject pdfDoc, int pageNum);
 int    PDFDoc_getPageRotate(XPDFObject pdfDoc, int pageNum);

 int PDFDoc_getNumPages(XPDFObject pdfDoc);
 
 const char* PDFDoc_getMetaData(XPDFObject pdfDoc);

 
 /*
  * Rendering
  */
 RenderResult Renderer_render(XPDFObject     pdfDoc,
                              void*          outputFunc,
                              void*          outputStream,
                              OutputOptions* options);

#ifdef __cplusplus 
};
#endif



#endif
