
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL

#ifndef _H_GHOSTSCRIPT
#define _H_GHOSTSCRIPT

#ifdef MACOSX
#import <Foundation/NSObject.h>
#import <Foundation/NSGeometry.h>
#else
#include <Foundation/NSObject.h>
#include <Foundation/NSGeometry.h>
#endif

// we use forward declarations here because
// Cocoas header files seem to be not include-safe.
@class NSTask;
@class NSPipe;
@class NSFileHandle;
@class NSData;
@class NSArray;
@class NSString;
@class NSLock;
@class NSImage;


#define DEFAULT_X_RESOLUTION 72
#define DEFAULT_Y_RESOLUTION 72


@interface Ghostscript : NSObject
{
   NSTask*       gsTask;

   NSString*     gsExecutable;
   NSPipe*       toGsPipe;
   NSFileHandle* toGs;
   NSPipe*       fromGsPipe;
   NSFileHandle* fromGs;
   BOOL          needStartGs;

   NSString*     tempFileName;
   int           nextOutputPageIndex;
   NSLock*       gsAccessLock;

   int           xRes;
   int           yRes;
   NSSize        pageSize;
}

+ (void) initialize;

- (id) initWithGsExecutable: (NSString*)pathToGsExecutable;
- (void) dealloc;

- (void) prepareForTermination;

- (void) setXRes: (int)newXRes yRes: (int)newYRes;
- (int) xRes;
- (int) yRes;
- (void) setPageSize: (NSSize)size;
- (NSSize) pageSize;

- (void) acquireAccess;
- (void) releaseAccess;
- (void) sendCommand: (NSString*)aCommand;
- (void) sendData: (NSData*)data;

- (id) nextImage: (id) handler;
- (NSArray*) nextImages: (int)count withHandler: (id)handler;

@end


@interface Ghostscript(OutputHandling)
- (id)handleGSOutput: (NSString*)gsOutputFile;
@end

#endif
