
// created 06.2003 by Stefan Kleine Stegemann
// 
// licensed under GPL

#ifndef _H_PAGE_CACHE
#define _H_PAGE_CACHE

#ifdef MACOSX
#import <Foundation/NSObject.h>
#else
#include <Foundation/NSObject.h>
#endif

@class NSImage;
@class NSMutableDictionary;
@class NSLock;
@class NSString;


@interface PageCache : NSObject
{
   id                    renderer;
   NSMutableDictionary*  cache;
   int                   cacheSize;
   int                   prefetchCount;
   NSLock*               cacheAccessLock;
   NSLock*               readAccessLock;
   id                    cacheLoader;
   int                   nextPageNumber;
   int                   basePageForNextPage;
   id                    notificationObject;
}

- (id) initWithRenderer: (id)aRenderer
              cacheSize: (int)maxPagesInCache
          prefetchCount: (int)numPages
     notificationObject: (id)anObject;
- (void) dealloc;
+ (void) initialize;

- (void) startCaching;

- (int) cacheSize;
- (int) prefetchCount;
- (id) renderer;
- (id) notificationObject;

- (void) acquireCacheAccess;
- (void) releaseCacheAccess;
- (void) addToCache: (NSString*)imageFile
            pageNum: (int)num
           basePage: (int)page;
- (void) setNextHandledPageNumber: (int)pageNum withBasePage: (int)basePageNum;
- (BOOL) containsImageForPage: (int)page;

- (NSImage*)imageForPage: (int)pageNum;
- (void) invalidate;

@end

// Notifications about Cache-Load-Progress
#define CACHE_PROGRESS_NOTIFICATION         @"CACHE_PROGRESS_NOTIFICATION"
#define CACHE_PROGRESS_INFO_PREFETCH_COUNT  @"CACHE_PROGRESS_INFO_PREFETCH_COUNT"
#define CACHE_PROGRESS_INFO_PAGES_DONE      @"CACHE_PROGRESS_INFO_PAGES_DONE"

#endif
